The HentaiVerse

38267
2434
2474
16
Battle Time
Choose from the Battle Actions highlighted above, and use them to defeat your enemies listed to the right. When all enemies are reduced to zero Health, you win. If your Health reaches zero, you are defeated.

You evade the attack from Jerking Like Do A Jerky Dance.
Your spike shield hits Thundaga for 5 points of elec damage.
You counter Thundaga for 5864 points of void damage.
You parry the attack from Thundaga.
Your spike shield hits So Dark for 5 points of elec damage.
You counter So Dark for 2844 points of void damage.
You block the attack from So Dark.
You evade the attack from Loliloli-love.
Your spike shield hits Youshi164 for 23 points of elec damage.
Youshi164 hits you for 654 crushing damage.
Google Dancing Israelis gains the effect Deep Burns.
Your spike shield hits Google Dancing Israelis for 5 points of elec damage.
Google Dancing Israelis gains the effect Stunned.
You counter Google Dancing Israelis for 5026 points of void damage.
You block the attack from Google Dancing Israelis.
Thundaga gains the effect Penetrated Armor.
Void Strike hits Thundaga for 1716 void damage.
Dark Strike hits Thundaga for 576 dark damage.
You crit Thundaga for 7327 void damage.

Flee
Scan
FUS RO DAH
Orbital Friendship Cannon
Shield Bash | Vital Strike | Merciful Blow

Fiery Blast | Inferno | Flames of Loki
Freeze | Blizzard | Fimbulvetr
Shockblast | Chained Lightning | Wrath of Thor
Gale | Downburst | Storms of Njord
Smite | Banishment | Paradise Lost
Corruption | Disintegrate | Ragnarok
Drain | Weaken | Imperil
Slow | Sleep | Confuse
Blind | Silence | MagNet
Cure | Regen | Full-Cure
Protection | Haste | Shadow Veil
Absorb | Spark of Life | Spirit Shield
Heartseeker | Arcane Focus

P
1
Health Draught
2
Mana Draught
3
Spirit Draught
4
Health Potion
5
Mana Potion
6
Spirit Potion
7
Health Elixir
8
Mana Elixir
9
Spirit Elixir
10
Last Elixir
11
12
13
14
15
S1
Scroll of the Avatar
S2
Scroll of the Gods
S3
Scroll of Absorption
S4
Scroll of Life
S5
Scroll of Protection
S6
Scroll of Shadows
N1
N2
N3
N4
N5
N6
500
Google Dancing Israelis
500
Jerking Like Do A Jerky Dance
500
So Dark
500
Loliloli-love
500
Youshi164
500
Thundaga